@@ -14,7 +14,7 @@ class LanguageIdentifier:
     def rank(self, text:str):
         return self.model.rank(text)
 
-lid = LanguageIdentifier(Path("../models/LID_mixed_model.pkl"))
+lid = LanguageIdentifier(Path(__file__).parent/'LID_mixed_model.pkl')
 def predict(text:str):
     return lid.predict(text)
 def rank(text:str):
